@@ -23,13 +23,12 @@ class EvntalySDK:
         url = f"{self.BASE_URL}/api/v1/account/check-limits/{self.developer_secret}"
         headers = {
             "Content-Type": "application/json",
-            "X-Project-Token": self.project_token,
         }
         
         try:
             response = requests.get(url, headers=headers)
             response.raise_for_status()
-            return response.json().get("allowed", False)
+            return response.json().get("limitReached", False)
         except requests.RequestException as e:
             print(f"Error checking limit: {e}")
             return False
@@ -42,7 +41,7 @@ class EvntalySDK:
             print("Tracking is disabled. Event not sent.")
             return
 
-        if not self.check_limit():
+        if self.check_limit():
             print("checkLimit returned false. Event not sent.")
             return
 
